==> trusty-storage-infinispan-1.7.0.Final-sources.jar: org/kie/kogito/trusty/storage/infinispan/CounterfactualExplainabilityRequestMarshaller.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.trusty.storage.infinispan;

import java.io.IOException;
import java.util.ArrayList;

import org.kie.kogito.trusty.storage.api.model.CounterfactualExplainabilityRequest;
import org.kie.kogito.trusty.storage.api.model.CounterfactualSearchDomain;
import org.kie.kogito.trusty.storage.api.model.TypedVariableWithValue;

import com.fasterxml.jackson.databind.ObjectMapper;

public class CounterfactualExplainabilityRequestMarshaller extends AbstractModelMarshaller<CounterfactualExplainabilityRequest> {

    public CounterfactualExplainabilityRequestMarshaller(ObjectMapper mapper) {
        super(mapper, CounterfactualExplainabilityRequest.class);
    }

    @Override
    public CounterfactualExplainabilityRequest readFrom(ProtoStreamReader reader) throws IOException {
        return new CounterfactualExplainabilityRequest(
                reader.readString(CounterfactualExplainabilityRequest.EXECUTION_ID_FIELD),
                reader.readString(CounterfactualExplainabilityRequest.COUNTERFACTUAL_ID_FIELD),
                reader.readCollection(CounterfactualExplainabilityRequest.COUNTERFACTUAL_GOALS, new ArrayList<>(), TypedVariableWithValue.class),
                reader.readCollection(CounterfactualExplainabilityRequest.COUNTERFACTUAL_SEARCH_DOMAINS, new ArrayList<>(), CounterfactualSearchDomain.class));
    }

    @Override
    public void writeTo(ProtoStreamWriter writer, CounterfactualExplainabilityRequest input) throws IOException {
        writer.writeString(CounterfactualExplainabilityRequest.EXECUTION_ID_FIELD, input.getExecutionId());
        writer.writeString(CounterfactualExplainabilityRequest.COUNTERFACTUAL_ID_FIELD, input.getCounterfactualId());
        writer.writeCollection(CounterfactualExplainabilityRequest.COUNTERFACTUAL_GOALS, input.getGoals(), TypedVariableWithValue.class);
        writer.writeCollection(CounterfactualExplainabilityRequest.COUNTERFACTUAL_SEARCH_DOMAINS, input.getSearchDomains(), CounterfactualSearchDomain.class);
    }
}

==> trusty-storage-infinispan-1.8.0.Final-sources.jar: org/kie/kogito/trusty/storage/infinispan/CounterfactualExplainabilityRequestMarshaller.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.trusty.storage.infinispan;

import java.io.IOException;

import org.kie.kogito.trusty.storage.api.model.CounterfactualExplainabilityRequest;

import com.fasterxml.jackson.databind.ObjectMapper;

public class CounterfactualExplainabilityRequestMarshaller extends AbstractModelMarshaller<CounterfactualExplainabilityRequest> {

    public CounterfactualExplainabilityRequestMarshaller(ObjectMapper mapper) {
        super(mapper, CounterfactualExplainabilityRequest.class);
    }

    @Override
    public CounterfactualExplainabilityRequest readFrom(ProtoStreamReader reader) throws IOException {
        return mapper.readValue(reader.readString(Constants.RAW_OBJECT_FIELD), CounterfactualExplainabilityRequest.class);
    }

    @Override
    public void writeTo(ProtoStreamWriter writer, CounterfactualExplainabilityRequest input) throws IOException {
        writer.writeString(CounterfactualExplainabilityRequest.EXECUTION_ID_FIELD, input.getExecutionId());
        writer.writeString(CounterfactualExplainabilityRequest.COUNTERFACTUAL_ID_FIELD, input.getCounterfactualId());
        writer.writeString(Constants.RAW_OBJECT_FIELD, mapper.writeValueAsString(input));
    }
}
